@@ -8,10 +8,10 @@ import time
 from . import genera
 from ._version import __version__
 
-from .genera.rulefiles import rule2files
+from .genera import sanirule, genus_to_module, obtain_genus
 
 __all__ = ['lifelib_dir', 'compile_rules', 'load_rules', 'reset_tree',
-           'rule2files', 'run_tests', 'add_cygdir', 'install_cygwin']
+           'sanirule', 'run_tests', 'add_cygdir', 'install_cygwin']
 
 lifelib_dir = os.path.dirname(os.path.abspath(__file__))
 this_python = os.path.abspath(sys.executable)
@@ -286,13 +286,7 @@ def compile_rules(*rules, **kwargs):
 
 def load_rules(*rules, **kwargs):
 
-    rules = list(rules)
-
-    for i in range(len(rules)):
-        if '.' in rules[i]:
-            rules[i] = rule2files(rules[i])
-        else:
-            rules[i] = rules[i].lower()
+    rules = [sanirule(r) for r in rules]
 
     soname = compile_rules(*rules, **kwargs)
     from .pythlib import Session
@@ -424,12 +418,8 @@ def generate_code(rules, clean_before=False):
 
     logic_directory = 'avxlife/lifelogic'
 
-    # Determine rule families from genera:
-    try:
-        families = [genera.rule_property(r, 'family') for r in rules]
-    except ImportError:
-        print("ImportError; current directory == %s" % os.getcwd())
-        raise
+    # Ensure modules are importable:
+    modules = [genus_to_module(obtain_genus(rulestring)) for rulestring in rules]
 
     os.chdir(lifelib_dir)
 
@@ -441,6 +431,18 @@ def generate_code(rules, clean_before=False):
         os.makedirs(logic_directory)
     os.chdir(logic_directory)
 
+    # Create the source code for the rules:
+    for r in rules:
+
+        genera.create_rule(r)
+
+    # Determine rule families from genera:
+    try:
+        families = [genera.rule_property(r, 'family') for r in rules]
+    except ImportError:
+        print("ImportError; current directory == %s" % os.getcwd())
+        raise
+
     # Obtain integers describing valid mantissae:
     def mant2int(m):
         if hasattr(m, '__iter__'):
@@ -460,6 +462,18 @@ def generate_code(rules, clean_before=False):
 
         f.write('namespace apg {\n\n')
 
+        # Function to convert rulestring to rule integer:
+        not_used = True
+        f.write('    std::string get_zoi(std::string rule) {\n')
+        for (fam, r) in zip(families, rules):
+            if (fam >= 6):
+                f.write('        if (rule == "%s") { return "%s"; }\n' % (r, genera.rule_property(r, 'zoi')))
+                not_used = False
+        if not_used:
+            f.write('        (void) rule;\n')
+        f.write('        return "99";\n')
+        f.write('    }\n\n')
+
         # Function to convert rulestring to rule integer:
         f.write('    int rule2int(std::string rule) {\n')
         for (i, r) in enumerate(rules):
@@ -492,10 +506,5 @@ def generate_code(rules, clean_before=False):
 
         f.write('}\n')
 
-    # Create the source code for the rules:
-    for r in rules:
-
-        genera.create_rule(r)
-
     os.chdir(lifelib_dir)
 
