@@ -214,6 +214,27 @@ namespace apg {
             return celllist;
         }
 
+        bitworld& inplace_rot2() {
+            auto celllist = getcells();
+            for (auto it = celllist.begin(); it != celllist.end(); ++it) {
+                int x = it->first;
+                int y = it->second;
+                setcell(-x, -y, 1);
+            }
+            return *this;
+        }
+
+        bitworld& inplace_rot3() {
+            auto celllist = getcells();
+            for (auto it = celllist.begin(); it != celllist.end(); ++it) {
+                int x = it->first;
+                int y = it->second;
+                setcell(-y, x-y, 1);
+                setcell(y-x, -x, 1);
+            }
+            return *this;
+        }
+
         void printrepr() {
             std::map<std::pair<int32_t, int32_t>, uint64_t>::iterator it;
             for (it = world.begin(); it != world.end(); ++it ) {
