@@ -726,11 +726,23 @@ namespace apg {
 
 
             b0 = false;
-            if (rule[1] == '0') {
+            std::string subrule = rule;
+
+            // Strip Generations prefix:
+            if (subrule[0] == 'g') {
+                subrule = subrule.substr(1);
+                while ((subrule[0] >= '0') && (subrule[1] <= '9')) {
+                    subrule = subrule.substr(1);
+                }
+            }
+
+            if (uli_get_family(rule2int(rule)) >= 6) {
+                zoi = get_zoi(rule);
+            } else if ((subrule[0] == 'b') && (subrule[1] == '0')) {
                 zoi = "99"; b0 = true;
-            } else if (rule[0] == 'r') {
-                zoi = std::string(2 * (rule[1] - '0'), '9');
-            } else {
+            } else if (subrule[0] == 'r') {
+                zoi = std::string(2 * (subrule[1] - '0'), '9');
+            } else if (subrule[0] == 'b') {
                 pattern transpat(lab, transrle, rule);
                 bitworld bw = transpat[1].flatlayer(0);
                 for (int i = 0; i < 512; i++) {
@@ -739,6 +751,8 @@ namespace apg {
                     transtable[i] = bw.getcell(x, y);
                 }
                 zoi = (diagbirth()) ? "99" : "95";
+            } else {
+                zoi = get_zoi(rule);
             }
         }
     };
