@@ -2,6 +2,7 @@
 
 #include "hashtrees/hypertree.h"
 #include "bitworld.h"
+#include "sanirule.h"
 #include <map>
 #include <utility>
 #include <fstream>
@@ -245,7 +246,7 @@ namespace apg {
             */
             hypernode<I> hnode(0, 1);
             for (unsigned int i = 0; i < planes.size(); i++) {
-                hnode = boolean_universe(hnode, demorton(planes[i], 1 << i), 1);
+                hnode = boolean_universe(hnode, demorton(planes[i], 1ull << i), 1);
             }
             return hnode;
         }
@@ -254,14 +255,16 @@ namespace apg {
             return fromplanes(cells2vec(n, coords, states));
         }
 
-        hypernode<I> fromrle(std::string s) {
+        hypernode<I> fromrle(std::string s, RuleMapper *rm) {
             if (s != "") {
-                return fromplanes(rle2vec(s));
+                return fromplanes(rle2vec(s, rm));
             } else {
                 return hypernode<I>(0, 1);
             }
         }
 
+        hypernode<I> fromrle(std::string s) { return fromrle(s, 0); }
+
         virtual int rulestring_to_integer(std::string rulestring) = 0;
         virtual hypernode<I> iterate_recurse(hypernode<I> hnode, uint64_t mantissa, uint64_t exponent, int rule, int history) = 0;
 
@@ -477,18 +480,11 @@ namespace apg {
             return shift_universe(hn, nx, ny, 0);
         }
 
-        virtual hypernode<I> read_macrocell(std::istream &instream, std::map<uint64_t, uint64_t> *lmap, std::string &rule) = 0;
+        virtual hypernode<I> read_macrocell(std::istream &instream, std::string &rule) = 0;
 
         hypernode<I> load_macrocell(std::string filename, std::string &rule) {
             std::ifstream f(filename);
-            std::map<uint64_t, uint64_t> lmap;
-            lmap[0] = 0;
-            lmap[1] = 3;
-            lmap[2] = 2;
-            lmap[3] = 11;
-            lmap[4] = 10;
-            lmap[5] = 15;
-            return read_macrocell(f, 0, rule);
+            return read_macrocell(f, rule);
         }
 
         hypernode<I> load_macrocell(std::string filename, std::string &rule, int64_t x, int64_t y) {
