@@ -182,6 +182,12 @@ namespace apg {
 
     bitworld hashsoup(std::string prehash, std::string full_symmetry) {
 
+        if (full_symmetry.find("stdin") != std::string::npos) {
+            std::string rle = prehash.substr(prehash.find('-'));
+            auto bvec = rle2vec(rle);
+            return bvec[0];
+        }
+
         std::string symmetry = full_symmetry;
         uint64_t inflations = 0;
         while (symmetry[0] == 'i') {
